      program snlite
      implicit none
      include 'const.dek'

! models the radioactive portion of a supernova light curve

! declare
      integer :: i,nstep
      real*8  :: mass_56,mass_57,mass_44,mass_22,mass_60, &
                 number_56,number_57,number_44,number_22,number_60,bignum, &
                 tau_56,tau_57,tau_22,tau_44,tau_60,xln2, &
                 xk56,xk57,xk44,xk22,xk60

      real*8 ::  edot_gamma_56,edot_gamma_57,edot_gamma_44,edot_gamma_22,edot_gamma_60, &
                 edot_lepton_22max,edot_lepton_44max,edot_lepton_60max, &
                 edot_lepton_22ave,edot_lepton_44ave,edot_lepton_60ave, &
                 edot_lepton_22,edot_lepton_44,edot_lepton_60

      real*8 ::  xn56,xn57,xn44,xn22,xn60, & 
                 xl56,xl57,xl44,xl22,xl60,xltot, &
                 w,enu,dt,time_lo,time_hi,tday,t,rhor

      real*8, parameter ::  xx = me * clight * clight, mev2erg = ev2erg * 1.0d6


! mass_56 = mass of 56ni = co56 = fe56 produced in solar masses; from fransson & kozma
! mass_57 = mass of 57ni = co57 = fe57 produced; from fransson & kozma
! mass_44 = mass of ti44 produced in solar masses from fransson & kozma
! mass_22 = mass of na22 produced in solar masses from wph
! mass_60 = mass of co60 produced in solar masses from ww95

      mass_56 = 0.069d0
      mass_57 = 0.0033d0
      mass_44 = 1.0d-4
      mass_22 = 2.0e-6
      mass_60 = 2.0e-5


! number of atoms at time = 0
      bignum      = avo * msol
      number_56   = mass_56 * bignum / 56.0d0
      number_57   = mass_57 * bignum / 57.0d0
      number_44   = mass_44 * bignum / 44.0d0
      number_22   = mass_22 * bignum / 22.0d0
      number_60   = mass_60 * bignum / 60.0d0


! half lives in seconds
      xln2   = log(2.0d0)
      tau_56 = 77.226d0 * 24.0d0 * 3600.0d0 / xln2
      tau_57 = 271.0d0 * 24.0d0 * 3600.0d0 / xln2
      tau_44 = 60.3d0 * 3.16d7 / xln2
      tau_22 = 2.60d0 * 3.16d7 / xln2
      tau_60 = 5.27d0 * 3.16d7 / xln2


! escape fractions
      xk56 = 0.033d0
      xk57 = 2.4d0 * xk56
      xk44 = 0.04d0
      xk22 = 0.04d0
      xk60 = 0.04d0


! gamma ray and positron deposition energy rates in erg/sec
! 56co decay includes positron kinetic energy .125 mev and gamma ray energy 3.57
      edot_gamma_56     = number_56/tau_56 * (3.700d0) * mev2erg


! sum of gamma rays for co57, there is no positron
      edot_gamma_57     = number_57/tau_57 * (0.136d0) * mev2erg 


! sum of gamma rays and max electron kinetic energy for na22
      edot_gamma_22     = number_22/tau_22 * (1.275d0 + 2.0d0*0.511d0) * mev2erg
      edot_lepton_22max = 0.49d0
      w   = 1.0d0 + edot_lepton_22max/xx
      enu = 0.5d0 * w * xx * (1.0d0 - 1.0d0/(w*w)) * (1.0d0 - 1.0d0/(4.0d0*w) - 1.0d0/(9.0d0*w*w))
      edot_lepton_22ave = edot_lepton_22max - enu
      edot_lepton_22    = number_22/tau_22 * edot_lepton_22ave * mev2erg


! sum of gamma rays and max electron kinetic energy for ti44
      edot_gamma_44     = number_44/tau_44 * (1.159d0 + 2.0d0*0.511d0 + 0.068d0 + 0.078d0)*mev2erg
      edot_lepton_44max = 1.47d0
      w   = 1.0d0 + edot_lepton_44max/xx
      enu = 0.5d0 * w * xx * (1.0d0 - 1.0d0/(w*w)) * (1.0d0 - 1.0d0/(4.0d0*w) - 1.0d0/(9.0d0*w*w))
      edot_lepton_44ave = edot_lepton_44max - enu
      edot_lepton_44    = number_44/tau_44 * edot_lepton_44ave * mev2erg


! sum of gamma rays and max electron kinetic energy for co60
      edot_gamma_60     = number_60/tau_60 * (1.173d0 + 1.332d0) * mev2erg 
      edot_lepton_60max = 0.3178d0
      w   = 1.0d0 + edot_lepton_60max/xx
      enu = 0.5d0 * w * xx * (1.0d0 - 1.0d0/(w*w)) * (1.0d0 - 1.0d0/(4.0d0*w) - 1.0d0/(9.0d0*w*w))
      edot_lepton_60ave = edot_lepton_60max - enu
      edot_lepton_60    = number_60/tau_60 * edot_lepton_60ave * mev2erg


! write a header
      open(unit=2,file='example.dat',status='unknown')
      write(2,10) 'day','lco56','lco57','lti44','lna22','lco60','ltot'
10    format(1x,t6,a,t17,a,t28,a,t39,a,t50,a,t61,a,t72,a)



! dt is the time step in days
! time_lo is the starting time in days
! time_hi is the ending time in days

      dt      = 10.0d0
      time_lo = 500.0d0
      time_hi = 4500.0d0
      nstep   = int((time_hi - time_lo)/dt) + 1

      do 100  i=1,nstep
       tday = time_lo + float(i-1) * dt
       t    = tday * 24.d0 * 3600.d0


! model 10hmm column depth
       rhor = 7.0d4 * (1.0d6/t)**2


! decay the number of nuclei
       xn56 = number_56 * exp(-t/tau_56)
       xn57 = number_57 * exp(-t/tau_57)
       xn44 = number_44 * exp(-t/tau_44)
       xn22 = number_22 * exp(-t/tau_22)
       xn60 = number_60 * exp(-t/tau_60)


! decay the luminosities
! no integral to do because bolometric luminosity = edot on the tail

       xl56  = edot_gamma_56 * (1.0d0 - exp(-xk56*rhor)) * exp(-t/tau_56)
       xl57  = edot_gamma_57 * (1.0d0 - exp(-xk57*rhor)) * exp(-t/tau_57)
       xl44  = (edot_gamma_44 * (1.0d0 - exp(-xk44*rhor)) + edot_lepton_44) * exp(-t/tau_44)
       xl60  = (edot_gamma_60 * (1.0d0 - exp(-xk60*rhor)) + edot_lepton_60) * exp(-t/tau_60)
       xl22  = (edot_gamma_22 * (1.0d0 - exp(-xk22*rhor)) + edot_lepton_22) * exp(-t/tau_22)
       xltot = xl56 + xl57 + xl22 + xl44 + xl60


! log and write out what we got
       xl56  = log10(xl56)
       xl57  = log10(xl57)
       xl44  = log10(xl44)
       xl60  = log10(xl60)
       xl22  = log10(xl22)
       xltot = log10(xltot)

! write what we got
       write(2,20) tday,xl56,xl57,xl44,xl22,xl60,xltot
20     format(1x,1p7e14.6)

! back for another time point
100   continue

      close(unit=2)

      end program snlite
